%global uid 47
%global username ladvd
%global homedir %{_localstatedir}/run/%{name}
%global gecos CDP/LLDP sender for unix

%define selinux_variants mls strict targeted
%global selinux_policyver %(%{__sed} -e 's,.*selinux-policy-\\([^/]*\\)/.*,\\1,' /usr/share/selinux/devel/policyhelp || echo 0.0.0)
%define modulename ladvd

Name:           ladvd
Version:        0.9.2
Release:        4%{?dist}
Summary:        CDP/LLDP sender for unix

Group:          Applications/Internet
License:        ISC
URL:            http://www.blinkenlights.nl/software/ladvd/
Source0:        http://www.blinkenlights.nl/software/ladvd/ladvd-%{version}.tar.gz
Source1:        ladvd.sysconfig
Source2:        ladvd.init
Source3:        %{modulename}.te
Source4:        %{modulename}.fc
Source5:        %{modulename}.if
Source6:        ladvd.tmpfiles
Source7:        ladvd.service
# proposed upstream: http://code.google.com/p/ladvd/issues/detail?id=6
Patch0:         ladvd-0.9.2-add-attribute-unused-to-tlv.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  libevent-devel
BuildRequires:  pkgconfig
BuildRequires:  libcap-ng-devel

%bcond_without  fedora
BuildRequires:  fedora-usermgmt-devel
%{?FE_USERADD_REQ}

Provides:       group(%username) = %uid
Provides:       user(%username)  = %uid

Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
Requires(preun): /sbin/service
Requires:        systemd-units
Requires:        initscripts


%description 
ladvd uses cdp / lldp frames to inform switches about connected hosts, which
simplifies ethernet switch management. Every 30 seconds it will transmit CDP/
LLDP packets reflecting the current system state. Interfaces (bridge, bonding,
wireless), capabilities (bridging, forwarding, wireless) and addresses (IPv4,
IPv6) are detected dynamically.


%package selinux
Summary:        SELinux policy module supporting %{name}
Group:          System Environment/Base
BuildRequires:  checkpolicy, selinux-policy-devel, hardlink
%if "%{selinux_policyver}" != ""
Requires:       selinux-policy >= %{selinux_policyver}
%endif
Requires:       %{name} = %{version}-%{release}
Requires(post):   /usr/sbin/semodule, /sbin/restorecon
Requires(postun): /usr/sbin/semodule, /sbin/restorecon


%description selinux
SELinux policy module supporting %{name}


%prep
%setup -q
mkdir SELinux
cp -p %{SOURCE3} %{SOURCE4} %{SOURCE5} SELinux
%patch0 -p1

%build
%configure \
        --with-user=%username \
        --with-pid-dir=%{_localstatedir}/run
make %{?_smp_mflags}

cd SELinux
for selinuxvariant in %{selinux_variants}
do
make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile
mv %{modulename}.pp %{modulename}.pp.${selinuxvariant}
make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean
done
cd -


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
rm -rf %{buildroot}%{_docdir}/ladvd
install -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -D -m 755 %{SOURCE2} %{buildroot}%{_initrddir}/%{name}
mkdir -p %{buildroot}%{homedir}
mkdir -p %{buildroot}%{_sysconfdir}/tmpfiles.d
install -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/tmpfiles.d/%{name}.conf
mkdir -p %{buildroot}/lib/systemd/system/
cp -p %SOURCE7 %{buildroot}/lib/systemd/system/


cd SELinux
for selinuxvariant in %{selinux_variants}
do
install -d %{buildroot}%{_datadir}/selinux/${selinuxvariant}
install -p -m 644 %{modulename}.pp.${selinuxvariant} \
%{buildroot}%{_datadir}/selinux/${selinuxvariant}/%{modulename}.pp
done
cd -

/usr/sbin/hardlink -cv %{buildroot}%{_datadir}/selinux


%clean
rm -rf %{buildroot}


%pre
%__fe_groupadd %uid -r %username &>/dev/null || :
%__fe_useradd  %uid -r -s /sbin/nologin -d %homedir -M          \
-c '%gecos' -g %username %username &>/dev/null || :


%post
/sbin/chkconfig --add %{name}
/bin/systemctl daemon-reload >/dev/null 2>&1 :

%preun
if [ $1 = 0 ]; then
        /sbin/service %{name} stop >/dev/null 2>&1
        /sbin/chkconfig --del %{name}
fi


%postun
if [ "$1" -ge "1" ]; then
        /sbin/service %{name} condrestart >/dev/null 2>&1
fi
%__fe_userdel  %username &>/dev/null || :
%__fe_groupdel %username &>/dev/null || :


%post selinux
for selinuxvariant in %{selinux_variants}
do
/usr/sbin/semodule -s ${selinuxvariant} -i \
%{_datadir}/selinux/${selinuxvariant}/%{modulename}.pp &> /dev/null || :
done
/sbin/restorecon %{_localstatedir}/cache/myapp || :

%postun selinux
if [ $1 -eq 0 ] ; then
for selinuxvariant in %{selinux_variants}
do
/usr/sbin/semodule -s ${selinuxvariant} -r %{modulename} &> /dev/null || :
done
[ -d %{_localstatedir}/cache/myapp ]  && \
/sbin/restorecon -R %{_localstatedir}/cache/myapp &> /dev/null || :
fi

%triggerun -- ladvd < 0.9.2.-2
if /sbin/chkconfig --level 3 ladvd ; then
        /bin/systemctl enable ladvd.service >/dev/null 2>&1 || :
fi


%files
%defattr(-,root,root,-)
%doc doc/ChangeLog doc/README doc/LICENSE doc/TODO
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_initrddir}/%{name}
%{_sbindir}/%{name}
%{_sbindir}/%{name}c
%{_mandir}/man8/%{name}.8*
%{_mandir}/man8/%{name}c.8*
%ghost %attr(0755,root,root) %dir %{_localstatedir}/run/%{name}
%config(noreplace) %{_sysconfdir}/tmpfiles.d/%{name}.conf
/lib/systemd/system/%{name}.service


%files selinux
%defattr(-,root,root,0755)
%doc SELinux/*
%{_datadir}/selinux/*/%{modulename}.pp


%changelog
* Fri May 6 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-4
- Fix systemd-related scriptlets (from Bill Nottingham):

    - since we install a systemd service file, run 'systemctl daemon-reload'
    - chkconfig without a level forwards to systemctl, which is not useful for
      SysV migrations. Pass an explicit level.

* Sun Feb 13 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-3
- fix FTBFS caused by -Werror=unused-but-set-variable 

* Sun Feb 13 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-2
- provide systemd and tmpfiles integration bits

* Sun Feb 13 2011 Tomasz Torcz <ttorcz@fedoraproject.org> - 0.9.2-1
- new upstream version 0.9.2
- package ladvdc - client command
- simplify initscript, rely on protocol autodetection like upstream suggests
- move homedir to /var/run/ladvd

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Aug 26 2009 Andreas Thienemann <andreas@bawue.net> - 0.8-1
- Rebase to new upstream release

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Oct 18 2008 Andreas Thienemann <andreas@bawue.net> 0.6.1-2
- Added SElinux support package
- Added patch to make it build on EL-4
- Added separate ladvd user

* Sat Oct 18 2008 Andreas Thienemann <andreas@bawue.net> 0.6.1-1
- Initial package
